@@ -6,6 +6,7 @@ from sentry_sdk.ai.monitoring import record_token_usage
 from sentry_sdk.ai.utils import (
     set_data_normalized,
     normalize_message_roles,
+    truncate_and_annotate_messages,
     get_start_span_function,
 )
 from sentry_sdk.consts import OP, SPANDATA, SPANSTATUS
@@ -21,9 +22,14 @@ from sentry_sdk.utils import (
 
 try:
     try:
-        from anthropic import NOT_GIVEN
+        from anthropic import NotGiven
     except ImportError:
-        NOT_GIVEN = None
+        NotGiven = None
+
+    try:
+        from anthropic import Omit
+    except ImportError:
+        Omit = None
 
     from anthropic.resources import AsyncMessages, Messages
 
@@ -145,12 +151,14 @@ def _set_input_data(span, kwargs, integration):
                 normalized_messages.append(message)
 
         role_normalized_messages = normalize_message_roles(normalized_messages)
-        set_data_normalized(
-            span,
-            SPANDATA.GEN_AI_REQUEST_MESSAGES,
-            role_normalized_messages,
-            unpack=False,
+        scope = sentry_sdk.get_current_scope()
+        messages_data = truncate_and_annotate_messages(
+            role_normalized_messages, span, scope
         )
+        if messages_data is not None:
+            set_data_normalized(
+                span, SPANDATA.GEN_AI_REQUEST_MESSAGES, messages_data, unpack=False
+            )
 
     set_data_normalized(
         span, SPANDATA.GEN_AI_RESPONSE_STREAMING, kwargs.get("stream", False)
@@ -165,12 +173,13 @@ def _set_input_data(span, kwargs, integration):
     }
     for key, attribute in kwargs_keys_to_attributes.items():
         value = kwargs.get(key)
-        if value is not NOT_GIVEN and value is not None:
+
+        if value is not None and _is_given(value):
             set_data_normalized(span, attribute, value)
 
     # Input attributes: Tools
     tools = kwargs.get("tools")
-    if tools is not NOT_GIVEN and tools is not None and len(tools) > 0:
+    if tools is not None and _is_given(tools) and len(tools) > 0:
         set_data_normalized(
             span, SPANDATA.GEN_AI_REQUEST_AVAILABLE_TOOLS, safe_serialize(tools)
         )
@@ -416,3 +425,15 @@ def _wrap_message_create_async(f):
                     span.__exit__(None, None, None)
 
     return _sentry_patched_create_async
+
+
+def _is_given(obj):
+    # type: (Any) -> bool
+    """
+    Check for givenness safely across different anthropic versions.
+    """
+    if NotGiven is not None and isinstance(obj, NotGiven):
+        return False
+    if Omit is not None and isinstance(obj, Omit):
+        return False
+    return True
